@@ -1,7 +1,11 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """Procreation operators meant to be used in symmetry-constrained
 genetic algorithm (SCGA)."""
-from ..settings import adsorbate_elements, site_heights
-from ..utilities import is_list_or_tuple, get_depth
+from ..settings import site_heights
+from ..utilities import (custom_warning, 
+                         is_list_or_tuple, 
+                         get_depth)
 from ..adsorption_sites import (ClusterAdsorptionSites,    
                                 SlabAdsorptionSites)
 from ..adsorbate_coverage import (ClusterAdsorbateCoverage,
@@ -13,6 +17,7 @@ from collections import defaultdict
 from operator import attrgetter
 import warnings
 import random
+warnings.formatwarning = custom_warning
 
 
 class Mutation(OffspringCreator):
@@ -376,7 +381,7 @@ class AdsorbateGroupSubstitute(Mutation):
         atoms = atoms.copy() 
         if True in atoms.pbc:                                          
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(atoms)
             else:
                 sas = SlabAdsorptionSites(atoms, **self.kwargs)
@@ -384,7 +389,7 @@ class AdsorbateGroupSubstitute(Mutation):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(atoms)
             else:
                 sas = ClusterAdsorptionSites(atoms, **self.kwargs)
@@ -499,9 +504,7 @@ class AdsorbateGroupSubstitute(Mutation):
 
     def get_new_individual(self, parents):
         f = parents[0]
-        print('f: {}'.format(f))
         indi = self.substitute(f)
-        print('indi: {}'.format(indi))
         indi = self.initialize_individual(f, indi) 
         if 'groups' in f.info['data']:
             indi.info['data']['groups'] = f.info['data']['groups']
@@ -612,7 +615,7 @@ class AdsorbateGroupPermutation(Mutation):
 
         if True in f.pbc:                                          
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(f)
             else:
                 sas = SlabAdsorptionSites(f, **self.kwargs)
@@ -620,7 +623,7 @@ class AdsorbateGroupPermutation(Mutation):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(f)
             else:
                 sas = ClusterAdsorptionSites(f, **self.kwargs)
