@@ -1,4 +1,7 @@
-from math import tanh, sqrt, exp
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+"""Implementation for evolutionary multitasking (EM)"""
+from math import tanh
 from operator import itemgetter
 from collections import defaultdict
 from ase.ga.population import Population
